@@ -56,50 +56,54 @@ void PQHandlingExternal::copyToClipboard(QString filename) {
 
 }
 
-void PQHandlingExternal::executeExternal(QString cmd, QString currentfile) {
+void PQHandlingExternal::executeExternal(QString exe, QString args, QString currentfile) {
 
     DBG << CURDATE << "PQHandlingExternal::executeExternal()" << NL
-        << CURDATE << "** cmd = " << cmd.toStdString() << NL
+        << CURDATE << "** exe = " << exe.toStdString() << NL
+        << CURDATE << "** args = " << args.toStdString() << NL
         << CURDATE << "** currentfile = " << currentfile.toStdString() << NL;
 
-    QString executable = "";
-    QStringList arguments = cmd.split(" ");
-    if(!arguments.at(0).startsWith("/")) {
-        executable = arguments.at(0);
-        arguments.removeFirst();
-    } else {
-
-        QString path = arguments[0];
-        int i;
-        for(i = 1; i < arguments.length(); ++i) {
-            path += " ";
-            path += arguments[i];
-            QFileInfo info(path);
-            if(info.exists() && info.isFile()) {
-                i += 1;
-                break;
-            }
-        }
-        if(i == arguments.length()) {
-            LOG << CURDATE << "PQHandlingExternal::executeExternal(): Error, unable to execute: " << cmd.toStdString() << NL;
-            return;
-        }
-        executable = path;
-        arguments.erase(arguments.begin(), arguments.begin()+i);
-    }
+    if(exe == "")
+        return;
 
     QFileInfo info(currentfile);
 
-    for(int i = 0; i < arguments.length(); ++i) {
-        if(arguments[i].contains("%f"))
-            arguments[i] = arguments[i].replace("%f", currentfile);
-        if(arguments[i].contains("%u"))
-            arguments[i] = arguments[i].replace("%u", info.fileName());
-        if(arguments[i].contains("%d"))
-            arguments[i] = arguments[i].replace("%d", info.absolutePath());
+    QStringList argslist;
+    QStringList argslist_tmp = args.split(" ");
+
+    for(auto &a : argslist_tmp) {
+#ifdef Q_OS_WIN
+        if(a.contains("%f"))
+            a = a.replace("%f", currentfile.replace("/","\\"));
+        if(args.contains("%u"))
+            a = a.replace("%u", info.fileName().replace("/","\\"));
+        if(a.contains("%d"))
+            a = a.replace("%d", info.absolutePath().replace("/","\\"));
+#else
+        if(a.contains("%f"))
+            a = a.replace("%f", currentfile);
+        if(args.contains("%u"))
+            a = a.replace("%u", info.fileName());
+        if(a.contains("%d"))
+            a = a.replace("%d", info.absolutePath());
+#endif
+        argslist << a;
     }
 
-    QProcess::startDetached(executable, arguments);
+#if QT_VERSION < QT_VERSION_CHECK(5, 10, 0)
+
+    QProcess::startDetached(exe, argslist);
+
+
+#else
+
+    QProcess proc;
+    proc.setProgram(QDir::toNativeSeparators(exe));
+    proc.setArguments(argslist);
+
+    proc.startDetached();
+
+#endif
 
 }
 
@@ -285,7 +289,7 @@ QVariantList PQHandlingExternal::getContextMenuEntries() {
     }
 
     QSqlQuery query(db);
-    query.prepare("SELECT command,desc,close FROM entries");
+    query.prepare("SELECT command,arguments,icon,desc,close FROM entries");
     if(!query.exec()) {
         LOG << CURDATE << "PQHandlingExternal::getContextMenuEntries(): SQL error, select: " << query.lastError().text().trimmed().toStdString() << NL;
         return ret;
@@ -294,15 +298,18 @@ QVariantList PQHandlingExternal::getContextMenuEntries() {
     while(query.next()) {
 
         const QString command = query.record().value(0).toString();
-        const QString desc = query.record().value(1).toString();
-        const QString close = query.record().value(2).toString();
+        const QString arguments = query.record().value(1).toString();
+        const QString icon = query.record().value(2).toString();
+        const QString desc = query.record().value(3).toString();
+        const QString close = query.record().value(4).toString();
 
         QStringList thisentry;
 
-        thisentry << command.split(" ").at(0);  // icon
+        thisentry << icon;      // icon (if specified)
         thisentry << command;   // executable
         thisentry << desc;      // name
         thisentry << close;     // close
+        thisentry << arguments; // command line arguments
 
         ret << thisentry;
 
@@ -350,8 +357,9 @@ void PQHandlingExternal::replaceContextMenuEntriesWithAvailable() {
             if(checkIfBinaryExists(m[2*i+1])) {
 
                 QSqlQuery query(db);
-                query.prepare("INSERT INTO entries (command,desc,close) VALUES(:cmd,:dsc,:cls)");
-                query.bindValue(":cmd", m[2*i+1]+" %f");
+                query.prepare("INSERT INTO entries (command,arguments,desc,close) VALUES(:cmd,:arg,:dsc,:cls)");
+                query.bindValue(":cmd", m[2*i+1]);
+                query.bindValue(":arg", "%f");
                 query.bindValue(":dsc", m[2*i]);
                 query.bindValue(":cls", "0");
                 if(!query.exec())
@@ -388,17 +396,17 @@ QString PQHandlingExternal::getIconPathFromTheme(QString binary) {
         // Setup path (this is the most likely directory) and format (PNG)
         QString path = QIcon::themeSearchPaths().at(i) + "/hicolor/32x32/apps/" + binary.trimmed() + ".png";
         if(QFile(path).exists())
-            return "file:" + path;
+            return "file:///" + path;
         else {
             // Also check a smaller version
             path = path.replace("32x32","22x22");
             if(QFile(path).exists())
-                return "file:" + path;
+                return "file:///" + path;
             else {
                 // And check 24x24, if not in the two before, it most likely is in here (e.g., shotwell on my system)
                 path = path.replace("22x22","24x24");
                 if(QFile(path).exists())
-                    return "file:" + path;
+                    return "file:///" + path;
             }
         }
 
@@ -406,15 +414,15 @@ QString PQHandlingExternal::getIconPathFromTheme(QString binary) {
 
         path = path.replace("22x22","32x32").replace(".png",".svg");
         if(QFile(path).exists())
-            return "file:" + path;
+            return "file:///" + path;
         else {
             path = path.replace("32x32","22x22");
             if(QFile(path).exists())
-                return "file:" + path;
+                return "file:///" + path;
             else {
                 path = path.replace("22x22","24x24");
                 if(QFile(path).exists())
-                    return "file:" + path;
+                    return "file:///" + path;
             }
         }
     }
@@ -600,15 +608,19 @@ void PQHandlingExternal::saveContextMenuEntries(QVariantList entries) {
 
             QVariantList entrylist = entry.toList();
 
-            const QString close = entrylist.at(3).toString();
             const QString cmd = entrylist.at(1).toString();
+            const QString args = entrylist.at(4).toString();
+            const QString icn = entrylist.at(0).toString();
             const QString dsc = entrylist.at(2).toString();
+            const QString close = entrylist.at(3).toString();
 
             if(cmd != "" && dsc != "") {
 
                 QSqlQuery query(db);
-                query.prepare("INSERT INTO entries (command,desc,close) VALUES(:cmd,:dsc,:cls)");
+                query.prepare("INSERT INTO entries (icon,command,arguments,desc,close) VALUES(:icn,:cmd,:arg,:dsc,:cls)");
                 query.bindValue(":cmd", cmd);
+                query.bindValue(":arg", args);
+                query.bindValue(":icn", icn);
                 query.bindValue(":dsc", dsc);
                 query.bindValue(":cls", close);
                 if(!query.exec())
@@ -626,3 +638,20 @@ QSize PQHandlingExternal::getScreenSize() {
     DBG << CURDATE << "PQHandlingExternal::getScreenSize()" << NL;
     return QApplication::primaryScreen()->size();
 }
+
+QString PQHandlingExternal::loadImageAndConvertToBase64(QString filename) {
+
+    PQHandlingFileDir filedir;
+    filename = filedir.cleanPath(filename);
+
+    QPixmap pix;
+    pix.load(filename);
+    if(pix.width() > 64 || pix.height() > 64)
+        pix = pix.scaled(64,64,Qt::KeepAspectRatio);
+    QByteArray bytes;
+    QBuffer buffer(&bytes);
+    buffer.open(QIODevice::WriteOnly);
+    pix.save(&buffer, "PNG");
+    return bytes.toBase64();
+
+}
