@@ -69,7 +69,7 @@ void PQHandlingFileDialog::addNewUserPlacesEntry(QString path, int pos) {
         // <bookmark>
         newnode.set_name("bookmark");
         newnode.append_attribute("href");
-        newnode.attribute("href").set_value(QString("file://%1").arg(path).toStdString().c_str());
+        newnode.attribute("href").set_value(QString("file:///%1").arg(path).toStdString().c_str());
 
         // <title>
         pugi::xml_node title = newnode.append_child("title");
@@ -122,7 +122,7 @@ void PQHandlingFileDialog::addNewUserPlacesEntry(QString path, int pos) {
                 // <bookmark>
                 newnode.set_name("bookmark");
                 newnode.append_attribute("href");
-                newnode.attribute("href").set_value(QString("file://%1").arg(path).toStdString().c_str());
+                newnode.attribute("href").set_value(QString("file:///%1").arg(path).toStdString().c_str());
 
                 // <title>
                 pugi::xml_node title = newnode.append_child("title");
@@ -261,13 +261,19 @@ QVariantList PQHandlingFileDialog::getStorageInfo() {
 
             QString name = s.name();
             if(name == "")
-                name = s.rootPath();
+                name = QDir::toNativeSeparators(s.rootPath());
+
+            QString p = s.rootPath();
+#ifdef Q_OS_WIN
+            if(p.endsWith("/"))
+                p = p.remove(p.length()-1, p.length());
+#endif
 
             QVariantList vol;
             vol << name
                 << s.bytesTotal()
                 << QString(s.fileSystemType())
-                << s.rootPath();
+                << p;
 
             ret.append(vol);
 
@@ -356,27 +362,23 @@ QVariantList PQHandlingFileDialog::getUserPlaces() {
 
         QString path = bm.attribute("href").value();
 
+        // we need to check for the old (wrong) syntax of two slashes
+        // and for the new right synbtax of three slashes after file:
 #ifdef Q_OS_WIN
-
         if(path.startsWith("file:///"))
             path = path.remove(0,8);
         else if(path.startsWith("file://"))
             path = path.remove(0,7);
-        else if(path.startsWith("file:/"))
-            path = path.remove(0,6);
-        else
-            continue;
-
 #else
-        if(path.startsWith("file:///"))
+        if(path.startsWith("file:////"))
+            path = path.remove(0,8);
+        else if(path.startsWith("file:///"))
             path = path.remove(0,7);
-        else if(path.startsWith("file://"))
-            path = path.remove(0,6);
         else if(path == "trash:/")
             path = ConfigFiles::GENERIC_DATA_DIR() + "/Trash/files";
+#endif
         else
             continue;
-#endif
 
         // name
         entry << bm.select_node("title").node().child_value();
