@@ -43,7 +43,7 @@
 #include <FreeImagePlus.h>
 #endif
 #ifdef DEVIL
-#include <il.h>
+#include <IL/il.h>
 #endif
 #ifdef VIDEOMPV
 #include "../libmpv/mpvobject.h"
@@ -200,19 +200,11 @@ QStringList PQHandlingGeneral::getAvailableTranslations() {
 
     QStringList ret;
 
-    // these are shown first
-    // they are the ones with recent activity
-    // this list will be updated before release
-    // the other ones are shown afterwards sorted alphabetically
-    ret << "en";
-    ret << "de_DE";
-    ret << "es_ES";
-    ret << "lt_LT";
-    ret << "pl_PL";
-    ret << "pt_PT";
-
     QStringList tmp;
 
+    // the non-translated language is English
+    tmp << "en";
+
     QDirIterator it(":");
     while (it.hasNext()) {
         QString file = it.next();
@@ -263,7 +255,7 @@ QString PQHandlingGeneral::getConfigInfo(bool formatHTML) {
 #endif
 
 #ifdef POPPLER
-    txt += QString("- %1Poppler%2%3").arg(bold1, bold2, nl);
+    txt += QString("- %1Poppler%2: %3%4").arg(bold1, bold2, POPPLER_VERSION, nl);
 #endif
 #ifdef LIBARCHIVE
     txt += QString("- %1LibArchive%2: %3%4").arg(bold1, bold2, ARCHIVE_VERSION_ONLY_STRING, nl);
