@@ -152,7 +152,7 @@ void PQHandlingWallpaper::setWallpaper(QString category, QString filename, QVari
                           "d = allDesktops[i];"
                           "d.wallpaperPlugin = \"org.kde.image\"; "
                           "d.currentConfigGroup = Array(\"Wallpaper\", \"org.kde.image\", \"General\"); "
-                          "d.writeConfig(\"Image\", \"file://" + filename + "\");"
+                          "d.writeConfig(\"Image\", \"file:///" + filename + "\");"
                           "}";
 
             QDBusConnection bus = QDBusConnection::sessionBus();
@@ -179,7 +179,7 @@ void PQHandlingWallpaper::setWallpaper(QString category, QString filename, QVari
             LOG << CURDATE << "PQHandlingWallpaper::setWallpaper: ERROR: gsettings failed with exit code " << ret
                 << " - are you sure Gnome/Unity is installed?" << NL;
         else
-            proc.execute("gsettings", QStringList() << "set" << "org.gnome.desktop.background" << "picture-uri" << QString("file://%1").arg(filename));
+            proc.execute("gsettings", QStringList() << "set" << "org.gnome.desktop.background" << "picture-uri" << QString("file:///%1").arg(filename));
 
 
     } else if(category == "xfce") {
