@@ -25,8 +25,7 @@
 PQMetaData::PQMetaData(QObject *parent) : QObject(parent) {
 
     m_validFile = true;
-    m_fileSize = "";
-    m_dimensions = "";
+    m_fileSize = 0;
 
     m_exifImageMake = "";
     m_exifImageModel = "";
@@ -51,6 +50,28 @@ PQMetaData::PQMetaData(QObject *parent) : QObject(parent) {
 
 }
 
+void PQMetaData::setEmptyExivData() {
+
+    setExifImageMake("");
+    setExifImageModel("");
+    setExifImageSoftware("");
+    setExifPhotoDateTimeOriginal("");
+    setExifPhotoExposureTime("");
+    setExifPhotoFlash("");
+    setExifPhotoISOSpeedRatings("");
+    setExifPhotoSceneCaptureType("");
+    setExifPhotoFocalLength("");
+    setExifPhotoFNumber("");
+    setExifPhotoLightSource("");
+    setExifPhotoPixelXDimension("");
+    setExifPhotoPixelYDimension("");
+    setExifGPS("");
+    setIptcApplication2Keywords("");
+    setIptcLocation("");
+    setIptcApplication2Copyright("");
+
+}
+
 void PQMetaData::updateMetadata(QString path) {
 
     DBG << CURDATE << "PQMetaData::updateMetadata()" << NL
@@ -75,49 +96,7 @@ void PQMetaData::updateMetadata(QString path) {
 
     setValidFile(true);
 
-    setFileSize(QString("%1 KB").arg(info.size()/1024.0));
-
-    // Obtain dimensions (if supported by ImageReader)
-    if(QImageReader::supportedImageFormats().contains(info.suffix().toLower().toUtf8())) {
-        QSize s = QImageReader(path).size();
-        if(s.width() > 0 && s.height() > 0)
-            setDimensions(QString("%1x%2").arg(s.width()).arg(s.height()));
-        else
-            setDimensions("");
-    } else
-        setDimensions("");
-
-    // These formats are supported by exiv2
-    QStringList formats;
-    formats << "jpeg" << "jpg" << "tif" << "tiff"
-            << "png" << "psd" << "jpeg2000" << "jp2"
-            << "j2k" << "jpc" << "jpf" << "jpx"
-            << "jpm" << "mj2" << "bmp" << "bitmap"
-            << "gif" << "tga";
-
-    if(!formats.contains(info.suffix().toLower())) {
-
-        setExifImageMake("");
-        setExifImageModel("");
-        setExifImageSoftware("");
-        setExifPhotoDateTimeOriginal("");
-        setExifPhotoExposureTime("");
-        setExifPhotoFlash("");
-        setExifPhotoISOSpeedRatings("");
-        setExifPhotoSceneCaptureType("");
-        setExifPhotoFocalLength("");
-        setExifPhotoFNumber("");
-        setExifPhotoLightSource("");
-        setExifPhotoPixelXDimension("");
-        setExifPhotoPixelYDimension("");
-        setExifGPS("");
-        setIptcApplication2Keywords("");
-        setIptcLocation("");
-        setIptcApplication2Copyright("");
-
-        return;
-
-    }
+    setFileSize(info.size());
 
 #ifdef EXIV2
 
@@ -132,7 +111,13 @@ void PQMetaData::updateMetadata(QString path) {
         image  = Exiv2::ImageFactory::open(path.toStdString());
         image->readMetadata();
     } catch (Exiv2::Error& e) {
-        LOG << CURDATE << "PQMetaData::updateMetadaya(): ERROR reading exiv data (caught exception): " << e.what() << NL;
+        // An error code of 11 means unknown file type
+        // Since we always try to read any file's meta data, this happens a lot
+        if(e.code() != 11)
+            LOG << CURDATE << "PQMetaData::updateMetadaya(): ERROR reading exiv data (caught exception): " << e.what() << NL;
+        else
+            DBG << CURDATE << "PQMetaData::updateMetadaya(): ERROR reading exiv data (caught exception): " << e.what() << NL;
+        setEmptyExivData();
         return;
     }
 
@@ -147,6 +132,8 @@ void PQMetaData::updateMetadata(QString path) {
         exifData = image->exifData();
     } catch(Exiv2::Error &e) {
         LOG << CURDATE << "PQMetaData::updateMetaData(): ERROR: Unable to read exif metadata: " << e.what() << NL;
+        setEmptyExivData();
+        return;
     }
 
 
