@@ -50,6 +50,9 @@ PQImageFormats::PQImageFormats() {
             return;
         }
 
+        QFile f(tmppath);
+        f.setPermissions(f.permissions()|QFileDevice::WriteOwner);
+
         db.setDatabaseName(tmppath);
 
         if(!db.open()) {
@@ -80,6 +83,7 @@ void PQImageFormats::readFromDatabase() {
     formats.clear();
     formats_enabled.clear();
     formats_qt.clear();
+    formats_libvips.clear();
     formats_magick.clear();
     formats_libraw.clear();
     formats_poppler.clear();
@@ -88,9 +92,11 @@ void PQImageFormats::readFromDatabase() {
     formats_freeimage.clear();
     formats_archive.clear();
     formats_video.clear();
+    formats_libmpv.clear();
 
     mimetypes_enabled.clear();
     mimetypes_qt.clear();
+    mimetypes_libvips.clear();
     mimetypes_magick.clear();
     mimetypes_libraw.clear();
     mimetypes_poppler.clear();
@@ -99,6 +105,7 @@ void PQImageFormats::readFromDatabase() {
     mimetypes_freeimage.clear();
     mimetypes_archive.clear();
     mimetypes_video.clear();
+    mimetypes_libmpv.clear();
 
     magick.clear();
     magick_mimetype.clear();
@@ -115,6 +122,7 @@ void PQImageFormats::readFromDatabase() {
         const QString cat = query.record().value("category").toString();
         const int enabled = query.record().value("enabled").toInt();
         const int qt = query.record().value("qt").toInt();
+        const int libvips = query.record().value("libvips").toInt();
 #ifdef IMAGEMAGICK
         const int imgmmagick = query.record().value("imagemagick").toInt();
 #elif defined(GRAPHICSMAGICK)
@@ -127,6 +135,7 @@ void PQImageFormats::readFromDatabase() {
         const int freeimage = query.record().value("freeimage").toInt();
         const int archive = query.record().value("archive").toInt();
         const int video = query.record().value("video").toInt();
+        const int libmpv = query.record().value("libmpv").toInt();
         const QString im_gm_magick = query.record().value("im_gm_magick").toString();
         const QString qt_formatname = query.record().value("qt_formatname").toString();
 
@@ -149,6 +158,19 @@ void PQImageFormats::readFromDatabase() {
                     mimetypes_qt << mimetypes.split(",");
             }
         }
+
+#ifdef LIBVIPS
+        if(libvips) {
+            supportedByAnyLibrary = true;
+            all << "libvips";
+            formats_libvips << endings.split(",");
+            if(mimetypes != "")
+                mimetypes_libvips << mimetypes.split(",");
+        }
+#endif
+
+        QStringList validImGmMagick;
+
 #if defined(IMAGEMAGICK) || defined(GRAPHICSMAGICK)
         if(imgmmagick) {
 
@@ -157,13 +179,22 @@ void PQImageFormats::readFromDatabase() {
             // or when it is reported as not readable, then we skip this format
             bool alright = true;
             if(im_gm_magick != "") {
-                try {
-                    Magick::CoderInfo magickCoderInfo(im_gm_magick.toStdString());
-                    if(!magickCoderInfo.isReadable())
-                        alright = false;
-                } catch(Magick::Exception &) {
-                    alright = false;
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
+                QStringList tmp = im_gm_magick.split(",", Qt::SkipEmptyParts);
+#else
+                QStringList tmp = im_gm_magick.split(",", QString::SkipEmptyParts);
+#endif
+
+                for(auto t: qAsConst(tmp)) {
+                    try {
+                        Magick::CoderInfo magickCoderInfo(t.toStdString());
+                        if(magickCoderInfo.isReadable())
+                            validImGmMagick << t;
+                    } catch(Magick::Exception &) {
+                        // do nothing here
+                    }
                 }
+                alright = (validImGmMagick.length()>0);
             }
 
             if(alright) {
@@ -232,7 +263,7 @@ void PQImageFormats::readFromDatabase() {
                 mimetypes_archive << mimetypes.split(",");
         }
 #endif
-#ifdef VIDEO
+#ifdef VIDEOQT
         if(video) {
             supportedByAnyLibrary = true;
             all << "Video";
@@ -241,6 +272,15 @@ void PQImageFormats::readFromDatabase() {
                 mimetypes_video << mimetypes.split(",");
         }
 #endif
+#ifdef VIDEOMPV
+        if(libmpv) {
+            supportedByAnyLibrary = true;
+            all << "libmpv";
+            formats_libmpv << endings.split(",");
+            if(mimetypes != "")
+                mimetypes_libmpv << mimetypes.split(",");
+        }
+#endif
 
         if(supportedByAnyLibrary) {
 
@@ -251,18 +291,18 @@ void PQImageFormats::readFromDatabase() {
                 if(mimetypes != "")
                     mimetypes_enabled << mimetypes.split(",");
             }
-            if(magickToBeAdded && im_gm_magick != "") {
+            if(magickToBeAdded && validImGmMagick.length() > 0) {
                 for(QString &e : endings.split(",")) {
                     if(magick.contains(e))
-                        magick[e] = QStringList() << magick[e].toStringList() << im_gm_magick;
+                        magick[e] = QStringList() << magick[e].toStringList() << validImGmMagick;
                     else
-                        magick.insert(e, QStringList() << im_gm_magick);
+                        magick.insert(e, QStringList() << validImGmMagick);
                 }
                 for(QString &mt : mimetypes.split(",")) {
                     if(magick_mimetype.contains(mt))
-                        magick_mimetype[mt] = QStringList() << magick_mimetype[mt].toStringList() << im_gm_magick;
+                        magick_mimetype[mt] = QStringList() << magick_mimetype[mt].toStringList() << validImGmMagick;
                     else
-                        magick_mimetype.insert(mt, QStringList() << im_gm_magick);
+                        magick_mimetype.insert(mt, QStringList() << validImGmMagick);
                 }
             }
 
@@ -366,6 +406,7 @@ QVariantMap PQImageFormats::getFormatsInfo(QString endings) {
     ret.insert("category", query.record().value("category"));
     ret.insert("enabled", query.record().value("enabled"));
     ret.insert("qt", query.record().value("qt"));
+    ret.insert("libvips", query.record().value("libvips"));
     ret.insert("imagemagick", query.record().value("imagemagick"));
     ret.insert("graphicsmagick", query.record().value("graphicsmagick"));
     ret.insert("libraw", query.record().value("libraw"));
@@ -375,6 +416,7 @@ QVariantMap PQImageFormats::getFormatsInfo(QString endings) {
     ret.insert("freeimage", query.record().value("freeimage"));
     ret.insert("archive", query.record().value("archive"));
     ret.insert("video", query.record().value("video"));
+    ret.insert("libmpv", query.record().value("libmpv"));
     ret.insert("im_gm_magick", query.record().value("im_gm_magick"));
     ret.insert("qt_formatname", query.record().value("qt_formatname"));
 
@@ -383,7 +425,7 @@ QVariantMap PQImageFormats::getFormatsInfo(QString endings) {
 }
 
 bool PQImageFormats::enterNewFormat(QString endings, QString mimetypes, QString description, QString category, int enabled,
-                                    int qt, int imagemagick, int graphicsmagick, int libraw, int poppler, int xcftools, int devil, int freeimage, int archive, int video,
+                                    int qt, int libvips, int imagemagick, int graphicsmagick, int libraw, int poppler, int xcftools, int devil, int freeimage, int archive, int video, int libmpv,
                                     QString im_gm_magick, QString qt_formatname,
                                     bool silentIfExists = false) {
 
@@ -410,7 +452,7 @@ bool PQImageFormats::enterNewFormat(QString endings, QString mimetypes, QString
     }
 
     QSqlQuery query2(db);
-    query2.prepare("INSERT INTO imageformats (endings, mimetypes, description, category, enabled, qt, imagemagick, graphicsmagick, libraw, poppler, xcftools, devil, freeimage, archive, video, im_gm_magick, qt_formatname) VALUES (:endings, :mimetypes, :description, :category, :enabled, :qt, :imagemagick, :graphicsmagick, :libraw, :poppler, :xcftools, :devil, :freeimage, :archive, :video, :im_gm_magick, :qt_formatname)");
+    query2.prepare("INSERT INTO imageformats (endings, mimetypes, description, category, enabled, qt, libvips, imagemagick, graphicsmagick, libraw, poppler, xcftools, devil, freeimage, archive, video, libmpv, im_gm_magick, qt_formatname) VALUES (:endings, :mimetypes, :description, :category, :enabled, :qt, :libvips, :imagemagick, :graphicsmagick, :libraw, :poppler, :xcftools, :devil, :freeimage, :archive, :video, :libmpv, :im_gm_magick, :qt_formatname)");
 
     query2.bindValue(":endings", endings);
     query2.bindValue(":mimetypes", mimetypes);
@@ -418,6 +460,7 @@ bool PQImageFormats::enterNewFormat(QString endings, QString mimetypes, QString
     query2.bindValue(":category", category);
     query2.bindValue(":enabled", enabled);
     query2.bindValue(":qt", qt);
+    query2.bindValue(":libvips", libvips);
     query2.bindValue(":imagemagick", imagemagick);
     query2.bindValue(":graphicsmagick", graphicsmagick);
     query2.bindValue(":libraw", libraw);
@@ -427,6 +470,7 @@ bool PQImageFormats::enterNewFormat(QString endings, QString mimetypes, QString
     query2.bindValue(":freeimage", freeimage);
     query2.bindValue(":archive", archive);
     query2.bindValue(":video", video);
+    query2.bindValue(":libmpv", libmpv);
     query2.bindValue(":im_gm_magick", im_gm_magick);
     query2.bindValue(":qt_formatname", qt_formatname);
 
@@ -443,6 +487,70 @@ bool PQImageFormats::enterNewFormat(QString endings, QString mimetypes, QString
 
 }
 
+bool PQImageFormats::updateFormatByEnding(QString endings, QString mimetypes, QString description, QString category, int enabled,
+                                          int qt, int libvips, int imagemagick, int graphicsmagick, int libraw, int poppler, int xcftools, int devil, int freeimage, int archive, int video, int libmpv,
+                                          QString im_gm_magick, QString qt_formatname,
+                                          bool silentIfExists = false) {
+
+    // first check that it doesn't exist yet
+
+    QSqlQuery query(db);
+    query.prepare("SELECT COUNT(endings) AS NumFormats FROM imageformats WHERE description=:description");
+    query.bindValue(":description", description);
+    if(!query.exec()) {
+        LOG << CURDATE << "PQImageFormats::updateFormatByEnding(): SQL Query error (1): " << query.lastError().text().trimmed().toStdString() << NL;
+        return false;
+    }
+
+    if(!query.next()) {
+        LOG << CURDATE << "PQImageFormats::updateFormatByEnding(): No SQL results returned" << NL;
+        return false;
+    }
+
+    // if it doesn't exist yet, then it might need to be entered as new
+    int howmany = query.record().value("NumFormats").toInt();
+    if(howmany != 1) {
+        return enterNewFormat(endings, mimetypes, description, category, enabled,
+                              qt, libvips, imagemagick, graphicsmagick, libraw, poppler, xcftools, devil, freeimage, archive, video, libmpv,
+                              im_gm_magick, qt_formatname, silentIfExists);
+    }
+
+    QSqlQuery query2(db);
+    query2.prepare("UPDATE imageformats SET  mimetypes=:mimetypes, description=:description, category=:category, enabled=:enabled, qt=:qt, imagemagick=:imagemagick, graphicsmagick=:graphicsmagick, libraw=:libraw, poppler=:poppler, xcftools=:xcftools, devil=:devil, freeimage=:freeimage, archive=:archive, video=:video, libmpv=:libmpv, im_gm_magick=:im_gm_magick, qt_formatname=:qt_formatname WHERE endings=:endings");
+
+    query2.bindValue(":endings", endings);
+    query2.bindValue(":mimetypes", mimetypes);
+    query2.bindValue(":description", description);
+    query2.bindValue(":category", category);
+    query2.bindValue(":enabled", enabled);
+    query2.bindValue(":qt", qt);
+    query2.bindValue(":libvips", libvips);
+    query2.bindValue(":imagemagick", imagemagick);
+    query2.bindValue(":graphicsmagick", graphicsmagick);
+    query2.bindValue(":libraw", libraw);
+    query2.bindValue(":poppler", poppler);
+    query2.bindValue(":xcftools", xcftools);
+    query2.bindValue(":devil", devil);
+    query2.bindValue(":freeimage", freeimage);
+    query2.bindValue(":archive", archive);
+    query2.bindValue(":video", video);
+    query2.bindValue(":libmpv", libmpv);
+    query2.bindValue(":im_gm_magick", im_gm_magick);
+    query2.bindValue(":qt_formatname", qt_formatname);
+
+    if(!query2.exec()) {
+        LOG << CURDATE << "PQImageFormats::updateFormatByEnding(): SQL Query error (2): " << query2.lastError().text().trimmed().toStdString() << NL;
+        return false;
+    }
+
+    // it is recommended to re-read the database after updating formats
+    // it is not done automatically as this function might be called multiple times
+    // thus it should be taken care of from whererever this function is called.
+
+    return true;
+
+}
+
 void PQImageFormats::restoreDefaults() {
 
     db.close();
