@@ -24,7 +24,7 @@ function checkComboForShortcut(combo, wheelDelta) {
 
     // if in viewer mode, pressing 'Escape' exits viewer mode
     if(combo == "Escape" && (filefoldermodel.isPQT || filefoldermodel.isARC)) {
-        labels.exitViewerMode()
+        statusinfo.exitViewerMode()
         return
     }
 
@@ -37,14 +37,15 @@ function checkComboForShortcut(combo, wheelDelta) {
 
 }
 
-function executeInternalFunction(func) {
-    whatToDoWithFoundShortcut(["",func])
+function executeInternalFunction(func, args) {
+    whatToDoWithFoundShortcut(["",func,args])
 }
 
 function whatToDoWithFoundShortcut(sh, wheelDelta) {
 
     var close = sh[0]
     var cmd = sh[1]
+    var args = sh[2]
 
     if(cmd === "__quit")
         toplevel.quitPhotoQt()
@@ -56,6 +57,8 @@ function whatToDoWithFoundShortcut(sh, wheelDelta) {
         imageitem.loadNextImage()
     else if(cmd === "__prev")
         imageitem.loadPrevImage()
+    else if(cmd === "__loadRandom")
+        imageitem.loadRandomImage()
     else if(cmd == "__contextMenu")
         contextmenu.showMenu()
     else if(cmd === "__about")
@@ -123,7 +126,7 @@ function whatToDoWithFoundShortcut(sh, wheelDelta) {
     else if(cmd === "__goToLast")
         imageitem.loadLastImage()
     else if(cmd === "__viewerMode")
-        labels.toggleViewerMode()
+        statusinfo.toggleViewerMode()
     else if(cmd === "__showFaceTags")
         PQSettings.metadataFaceTagsEnabled = !PQSettings.metadataFaceTagsEnabled
     else if(cmd === "__wallpaper")
@@ -147,8 +150,7 @@ function whatToDoWithFoundShortcut(sh, wheelDelta) {
     else if(cmd === "__tagFaces")
         loader.passOn("facetagger", "start", undefined)
     else if(cmd === "__chromecast") {
-        if(handlingGeneral.isChromecastEnabled())
-            loader.show("chromecast")
+        loader.show("chromecast")
     } else if(cmd === "__logging")
         loader.show("logging")
     else if(cmd === "__print")
@@ -160,8 +162,12 @@ function whatToDoWithFoundShortcut(sh, wheelDelta) {
         filefoldermodel.advancedSortMainView()
     } else if(cmd == "__onlineHelp")
         Qt.openUrlExternally("https://photoqt.org/man")
+    else if(cmd == "__fullscreenToggle")
+        PQSettings.interfaceWindowMode = !PQSettings.interfaceWindowMode
+    else if(cmd == "__fitInWindow")
+        PQSettings.imageviewFitInWindow = !PQSettings.imageviewFitInWindow
     else {
-        handlingExternal.executeExternal(cmd, filefoldermodel.currentFilePath)
+        handlingExternal.executeExternal(cmd, args, filefoldermodel.currentFilePath)
         if(close === "1")
             toplevel.closePhotoQt()
     }
